From a2a58982a34443ad0b76567c34d7ab5329bad39b Mon Sep 17 00:00:00 2001
From: Johannes Hommel <johannes.hommel@iws.uni-stuttgart.de>
Date: Tue, 25 Nov 2014 10:10:19 +0000
Subject: [PATCH] [naming] use dofIdxGlobal, vIdxGlobal, eIdxGlobal

As decided at the Dumux day.

Reviewed by Bernd.



git-svn-id: svn://svn.iws.uni-stuttgart.de/DUMUX/dumux/trunk@13782 2fb0f335-1f38-0410-981e-8018bf24f1b0
---
 .../fvmpfa/lmethod/fvmpfal2dpressure2p.hh     |  4 +-
 .../lmethod/fvmpfal2dpressure2padaptive.hh    | 10 +--
 .../lmethod/fvmpfal2dpressurevelocity2p.hh    |  8 +-
 .../fvmpfal2dpressurevelocity2padaptive.hh    | 12 +--
 .../fvmpfal3dinteractionvolumecontainer.hh    | 88 +++++++++----------
 ...fal3dinteractionvolumecontaineradaptive.hh | 56 ++++++------
 .../fvmpfa/lmethod/fvmpfal3dpressure2p.hh     | 12 +--
 .../lmethod/fvmpfal3dpressure2padaptive.hh    | 14 +--
 .../lmethod/fvmpfal3dpressurevelocity2p.hh    |  8 +-
 .../fvmpfal3dpressurevelocity2padaptive.hh    | 14 +--
 .../fvmpfa/omethod/fvmpfao2dpressure2p.hh     |  4 +-
 .../omethod/fvmpfao2dpressurevelocity2p.hh    |  8 +-
 .../2p2c/fv3dpressure2p2cadaptive.hh          |  8 +-
 .../freeflow/stokes/stokesvolumevariables.hh  |  2 +-
 dumux/geomechanics/el2p/el2passembler.hh      | 12 +--
 dumux/geomechanics/el2p/el2pbasemodel.hh      | 22 ++---
 dumux/geomechanics/el2p/el2pmodel.hh          | 20 ++---
 dumux/implicit/box/boxassembler.hh            | 10 +--
 dumux/implicit/box/intersectiontovertexbc.hh  |  4 +-
 dumux/implicit/cellcentered/ccassembler.hh    |  4 +-
 dumux/implicit/common/implicitassembler.hh    |  6 +-
 dumux/implicit/common/implicitmodel.hh        | 22 ++---
 dumux/io/artgridcreator.hh                    |  2 +-
 23 files changed, 175 insertions(+), 175 deletions(-)

diff --git a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal2dpressure2p.hh b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal2dpressure2p.hh
index adcc40751f..6da5c55b3b 100644
--- a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal2dpressure2p.hh
+++ b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal2dpressure2p.hh
@@ -1283,9 +1283,9 @@ void FvMpfaL2dPressure2p<TypeTag>::assemble()
     VertexIterator vEndIt = problem_.gridView().template end<dim>();
     for (VertexIterator vIt = problem_.gridView().template begin<dim>(); vIt != vEndIt; ++vIt)
     {
-        int globalVertIdx = problem_.variables().index(*vIt);
+        int vIdxGlobal = problem_.variables().index(*vIt);
 
-        InteractionVolume& interactionVolume = interactionVolumes_[globalVertIdx];
+        InteractionVolume& interactionVolume = interactionVolumes_[vIdxGlobal];
 
         if (interactionVolume.isInnerVolume())
         {
diff --git a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal2dpressure2padaptive.hh b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal2dpressure2padaptive.hh
index 07808a3201..e0766cf07e 100644
--- a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal2dpressure2padaptive.hh
+++ b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal2dpressure2padaptive.hh
@@ -1655,14 +1655,14 @@ void FvMpfaL2dPressure2pAdaptive<TypeTag>::printInteractionVolumes()
     VertexIterator vEndIt = problem_.gridView().template end<dim>();
     for (VertexIterator vIt = problem_.gridView().template begin<dim>(); vIt != vEndIt; ++vIt)
     {
-        int globalVertIdx = problem_.variables().index(*vIt);
+        int vIdxGlobal = problem_.variables().index(*vIt);
 
-        InteractionVolume& interactionVolume = interactionVolumes_[globalVertIdx];
+        InteractionVolume& interactionVolume = interactionVolumes_[vIdxGlobal];
 
         if (interactionVolume.getElementNumber() > 2)
         {
             interactionVolume.printInteractionVolumeInfo();
-            std::cout << "global vertex index: " << globalVertIdx << "\n";
+            std::cout << "global vertex index: " << vIdxGlobal << "\n";
             if (interactionVolume.getElementNumber() == 3)
             {
                 ElementPointer& elementPointer1 = interactionVolume.getSubVolumeElement(0);
@@ -1710,9 +1710,9 @@ void FvMpfaL2dPressure2pAdaptive<TypeTag>::assemble()
     VertexIterator vEndIt = problem_.gridView().template end<dim>();
     for (VertexIterator vIt = problem_.gridView().template begin<dim>(); vIt != vEndIt; ++vIt)
     {
-        int globalVertIdx = problem_.variables().index(*vIt);
+        int vIdxGlobal = problem_.variables().index(*vIt);
 
-        InteractionVolume& interactionVolume = interactionVolumes_[globalVertIdx];
+        InteractionVolume& interactionVolume = interactionVolumes_[vIdxGlobal];
 
         if (interactionVolume.isInnerVolume())
         {
diff --git a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal2dpressurevelocity2p.hh b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal2dpressurevelocity2p.hh
index fb5076f9c9..b891bff556 100644
--- a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal2dpressurevelocity2p.hh
+++ b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal2dpressurevelocity2p.hh
@@ -223,9 +223,9 @@ void FvMpfaL2dPressureVelocity2p<TypeTag>::calculateVelocity()
     VertexIterator vEndIt = problem_.gridView().template end<dim>();
     for (VertexIterator vIt = problem_.gridView().template begin<dim>(); vIt != vEndIt; ++vIt)
     {
-        int globalVertIdx = problem_.variables().index(*vIt);
+        int vIdxGlobal = problem_.variables().index(*vIt);
 
-        InteractionVolume& interactionVolume = this->interactionVolumes_[globalVertIdx];
+        InteractionVolume& interactionVolume = this->interactionVolumes_[vIdxGlobal];
 
         if (interactionVolume.isInnerVolume())
         {
@@ -318,10 +318,10 @@ void FvMpfaL2dPressureVelocity2p<TypeTag>::calculateVelocity(const Intersection&
     {
         int localVertIdx = referenceElement.subEntity(indexInInside, dim - 1, vIdx, dim);
 
-        int globalVertIdx = problem_.variables().index(
+        int vIdxGlobal = problem_.variables().index(
                 *((*elementPtrI).template subEntity < dim > (localVertIdx)));
 
-        InteractionVolume& interactionVolume = this->interactionVolumes_[globalVertIdx];
+        InteractionVolume& interactionVolume = this->interactionVolumes_[vIdxGlobal];
 
         if (interactionVolume.isInnerVolume())
         {
diff --git a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal2dpressurevelocity2padaptive.hh b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal2dpressurevelocity2padaptive.hh
index 97e7247d5d..c2e8c24340 100644
--- a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal2dpressurevelocity2padaptive.hh
+++ b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal2dpressurevelocity2padaptive.hh
@@ -232,9 +232,9 @@ void FvMpfaL2dPressureVelocity2pAdaptive<TypeTag>::calculateVelocity()
     VertexIterator vEndIt = problem_.gridView().template end<dim>();
     for (VertexIterator vIt = problem_.gridView().template begin<dim>(); vIt != vEndIt; ++vIt)
     {
-        int globalVertIdx = problem_.variables().index(*vIt);
+        int vIdxGlobal = problem_.variables().index(*vIt);
 
-        InteractionVolume& interactionVolume = this->interactionVolumes_[globalVertIdx];
+        InteractionVolume& interactionVolume = this->interactionVolumes_[vIdxGlobal];
 
         if (interactionVolume.isInnerVolume())
         {
@@ -375,19 +375,19 @@ void FvMpfaL2dPressureVelocity2pAdaptive<TypeTag>::calculateVelocity(const Inter
     {
         int localVertIdx = referenceElement.subEntity(faceIdx, dim - 1, vIdx, dim);
 
-        int globalVertIdx = 0;
+        int vIdxGlobal = 0;
                 if (levelI >= levelJ)
                 {
-                    globalVertIdx = problem_.variables().index(
+                    vIdxGlobal = problem_.variables().index(
                             *((*elementPtrI).template subEntity < dim > (localVertIdx)));
                 }
                 else
                 {
-                    globalVertIdx = problem_.variables().index(
+                    vIdxGlobal = problem_.variables().index(
                             *((*elementPtrJ).template subEntity < dim > (localVertIdx)));
                 }
 
-        InteractionVolume& interactionVolume = this->interactionVolumes_[globalVertIdx];
+        InteractionVolume& interactionVolume = this->interactionVolumes_[vIdxGlobal];
 
         if (interactionVolume.isInnerVolume())
         {
diff --git a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dinteractionvolumecontainer.hh b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dinteractionvolumecontainer.hh
index ebe4a7b450..2b46959284 100644
--- a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dinteractionvolumecontainer.hh
+++ b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dinteractionvolumecontainer.hh
@@ -320,37 +320,37 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeSubVolumeElements(const
 {
     int globalIdx = problem_.variables().index(element);
 
-    int globalVertIdx = problem_.variables().vertexMapper().map(element, 0, dim);
-    interactionVolumes_[globalVertIdx].setSubVolumeElement(element, 7);
-    elemVertMap[globalVertIdx][7] = globalIdx;
+    int vIdxGlobal = problem_.variables().vertexMapper().map(element, 0, dim);
+    interactionVolumes_[vIdxGlobal].setSubVolumeElement(element, 7);
+    elemVertMap[vIdxGlobal][7] = globalIdx;
 
-    globalVertIdx = problem_.variables().vertexMapper().map(element, 1, dim);
-    interactionVolumes_[globalVertIdx].setSubVolumeElement(element, 6);
-    elemVertMap[globalVertIdx][6] = globalIdx;
+    vIdxGlobal = problem_.variables().vertexMapper().map(element, 1, dim);
+    interactionVolumes_[vIdxGlobal].setSubVolumeElement(element, 6);
+    elemVertMap[vIdxGlobal][6] = globalIdx;
 
-    globalVertIdx = problem_.variables().vertexMapper().map(element, 2, dim);
-    interactionVolumes_[globalVertIdx].setSubVolumeElement(element, 5);
-    elemVertMap[globalVertIdx][5] = globalIdx;
+    vIdxGlobal = problem_.variables().vertexMapper().map(element, 2, dim);
+    interactionVolumes_[vIdxGlobal].setSubVolumeElement(element, 5);
+    elemVertMap[vIdxGlobal][5] = globalIdx;
 
-    globalVertIdx = problem_.variables().vertexMapper().map(element, 3, dim);
-    interactionVolumes_[globalVertIdx].setSubVolumeElement(element, 4);
-    elemVertMap[globalVertIdx][4] = globalIdx;
+    vIdxGlobal = problem_.variables().vertexMapper().map(element, 3, dim);
+    interactionVolumes_[vIdxGlobal].setSubVolumeElement(element, 4);
+    elemVertMap[vIdxGlobal][4] = globalIdx;
 
-    globalVertIdx = problem_.variables().vertexMapper().map(element, 4, dim);
-    interactionVolumes_[globalVertIdx].setSubVolumeElement(element, 3);
-    elemVertMap[globalVertIdx][3] = globalIdx;
+    vIdxGlobal = problem_.variables().vertexMapper().map(element, 4, dim);
+    interactionVolumes_[vIdxGlobal].setSubVolumeElement(element, 3);
+    elemVertMap[vIdxGlobal][3] = globalIdx;
 
-    globalVertIdx = problem_.variables().vertexMapper().map(element, 5, dim);
-    interactionVolumes_[globalVertIdx].setSubVolumeElement(element, 2);
-    elemVertMap[globalVertIdx][2] = globalIdx;
+    vIdxGlobal = problem_.variables().vertexMapper().map(element, 5, dim);
+    interactionVolumes_[vIdxGlobal].setSubVolumeElement(element, 2);
+    elemVertMap[vIdxGlobal][2] = globalIdx;
 
-    globalVertIdx = problem_.variables().vertexMapper().map(element, 6, dim);
-    interactionVolumes_[globalVertIdx].setSubVolumeElement(element, 1);
-    elemVertMap[globalVertIdx][1] = globalIdx;
+    vIdxGlobal = problem_.variables().vertexMapper().map(element, 6, dim);
+    interactionVolumes_[vIdxGlobal].setSubVolumeElement(element, 1);
+    elemVertMap[vIdxGlobal][1] = globalIdx;
 
-    globalVertIdx = problem_.variables().vertexMapper().map(element, 7, dim);
-    interactionVolumes_[globalVertIdx].setSubVolumeElement(element, 0);
-    elemVertMap[globalVertIdx][0] = globalIdx;
+    vIdxGlobal = problem_.variables().vertexMapper().map(element, 7, dim);
+    interactionVolumes_[vIdxGlobal].setSubVolumeElement(element, 0);
+    elemVertMap[vIdxGlobal][0] = globalIdx;
 }
 
 /*! \brief Stores information with respect to DUNE intersections in the interaction volumes
@@ -418,11 +418,11 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeIntersectionInfo(const E
             {
                 int localVertIdx = referenceElement.subEntity(indexInInside, 1, i, dim);
 
-                int globalVertIdx = problem_.variables().vertexMapper().map(element, localVertIdx, dim);
+                int vIdxGlobal = problem_.variables().vertexMapper().map(element, localVertIdx, dim);
 
-                InteractionVolume& interactionVolume = interactionVolumes_[globalVertIdx];
+                InteractionVolume& interactionVolume = interactionVolumes_[vIdxGlobal];
 
-                if (elemVertMap[globalVertIdx][0] == globalIdx)
+                if (elemVertMap[vIdxGlobal][0] == globalIdx)
                 {
                     if (indexInInside == 1)
                     {
@@ -476,7 +476,7 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeIntersectionInfo(const E
                         }
                     }
                 }
-                if (elemVertMap[globalVertIdx][1] == globalIdx)
+                if (elemVertMap[vIdxGlobal][1] == globalIdx)
                 {
                     if (indexInInside == 3)
                     {
@@ -530,7 +530,7 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeIntersectionInfo(const E
                         }
                     }
                 }
-                if (elemVertMap[globalVertIdx][2] == globalIdx)
+                if (elemVertMap[vIdxGlobal][2] == globalIdx)
                 {
                     if (indexInInside == 2)
                     {
@@ -584,7 +584,7 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeIntersectionInfo(const E
                         }
                     }
                 }
-                if (elemVertMap[globalVertIdx][3] == globalIdx)
+                if (elemVertMap[vIdxGlobal][3] == globalIdx)
                 {
                     if (indexInInside == 0)
                     {
@@ -638,7 +638,7 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeIntersectionInfo(const E
                         }
                     }
                 }
-                if (elemVertMap[globalVertIdx][4] == globalIdx)
+                if (elemVertMap[vIdxGlobal][4] == globalIdx)
                 {
                     if (indexInInside == 4)
                     {
@@ -692,7 +692,7 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeIntersectionInfo(const E
                         }
                     }
                 }
-                if (elemVertMap[globalVertIdx][5] == globalIdx)
+                if (elemVertMap[vIdxGlobal][5] == globalIdx)
                 {
                     if (indexInInside == 4)
                     {
@@ -747,7 +747,7 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeIntersectionInfo(const E
                         }
                     }
                 }
-                if (elemVertMap[globalVertIdx][6] == globalIdx)
+                if (elemVertMap[vIdxGlobal][6] == globalIdx)
                 {
                     if (indexInInside == 4)
                     {
@@ -801,7 +801,7 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeIntersectionInfo(const E
                         }
                     }
                 }
-                if (elemVertMap[globalVertIdx][7] == globalIdx)
+                if (elemVertMap[vIdxGlobal][7] == globalIdx)
                 {
                     if (indexInInside == 4)
                     {
@@ -857,7 +857,7 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeIntersectionInfo(const E
                 }
                 if (isIt->boundary())
                 {
-                    if (elemVertMap[globalVertIdx][0] == globalIdx)
+                    if (elemVertMap[vIdxGlobal][0] == globalIdx)
                     {
                         if (indexInInside == 1)
                         {
@@ -914,7 +914,7 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeIntersectionInfo(const E
                             }
                         }
                     }
-                    if (elemVertMap[globalVertIdx][1] == globalIdx)
+                    if (elemVertMap[vIdxGlobal][1] == globalIdx)
                     {
                         if (indexInInside == 3)
                         {
@@ -971,7 +971,7 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeIntersectionInfo(const E
                             }
                         }
                     }
-                    if (elemVertMap[globalVertIdx][2] == globalIdx)
+                    if (elemVertMap[vIdxGlobal][2] == globalIdx)
                     {
                         if (indexInInside == 2)
                         {
@@ -1028,7 +1028,7 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeIntersectionInfo(const E
                             }
                         }
                     }
-                    if (elemVertMap[globalVertIdx][3] == globalIdx)
+                    if (elemVertMap[vIdxGlobal][3] == globalIdx)
                     {
                         if (indexInInside == 0)
                         {
@@ -1085,7 +1085,7 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeIntersectionInfo(const E
                             }
                         }
                     }
-                    if (elemVertMap[globalVertIdx][4] == globalIdx)
+                    if (elemVertMap[vIdxGlobal][4] == globalIdx)
                     {
                         if (indexInInside == 4)
                         {
@@ -1142,7 +1142,7 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeIntersectionInfo(const E
                             }
                         }
                     }
-                    if (elemVertMap[globalVertIdx][5] == globalIdx)
+                    if (elemVertMap[vIdxGlobal][5] == globalIdx)
                     {
                         if (indexInInside == 4)
                         {
@@ -1199,7 +1199,7 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeIntersectionInfo(const E
                             }
                         }
                     }
-                    if (elemVertMap[globalVertIdx][6] == globalIdx)
+                    if (elemVertMap[vIdxGlobal][6] == globalIdx)
                     {
                         if (indexInInside == 4)
                         {
@@ -1256,7 +1256,7 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeIntersectionInfo(const E
                             }
                         }
                     }
-                    if (elemVertMap[globalVertIdx][7] == globalIdx)
+                    if (elemVertMap[vIdxGlobal][7] == globalIdx)
                     {
                         if (indexInInside == 4)
                         {
@@ -2064,9 +2064,9 @@ void FvMpfaL3dInteractionVolumeContainer<TypeTag>::storeInteractionVolumeInfo()
     VertexIterator vEndIt = problem_.gridView().template end<dim>();
     for (VertexIterator vIt = problem_.gridView().template begin<dim>(); vIt != vEndIt; ++vIt)
     {
-        int globalVertIdx = problem_.variables().index(*vIt);
+        int vIdxGlobal = problem_.variables().index(*vIt);
 
-        InteractionVolume& interactionVolume = interactionVolumes_[globalVertIdx];
+        InteractionVolume& interactionVolume = interactionVolumes_[vIdxGlobal];
 
         if (interactionVolume.getElementNumber() == 8)
         {
diff --git a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dinteractionvolumecontaineradaptive.hh b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dinteractionvolumecontaineradaptive.hh
index 1bd1698d11..eb3d3f6dbb 100644
--- a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dinteractionvolumecontaineradaptive.hh
+++ b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dinteractionvolumecontaineradaptive.hh
@@ -107,9 +107,9 @@ public:
      * have to be updated in an implicit treatment of the transport equation, it is necessary to get
      * the complete set of vertices on a face: 4 corners + all hanging nodes.
      */
-    std::set<int>& faceVerticeIndices(int globalElemIdx, int faceIdx)
+    std::set<int>& faceVerticeIndices(int eIdxGlobal, int faceIdx)
     {
-        return faceVertices_[globalElemIdx][faceIdx];
+        return faceVertices_[eIdxGlobal][faceIdx];
     }
 
     //! Constructs a FvMpfaL3dInteractionVolumeContainerAdaptive object
@@ -1651,9 +1651,9 @@ void FvMpfaL3dInteractionVolumeContainerAdaptive<TypeTag>::storeInteractionVolum
     VertexIterator vEndIt = problem_.gridView().template end<dim>();
     for (VertexIterator vIt = problem_.gridView().template begin<dim>(); vIt != vEndIt; ++vIt)
     {
-        int globalVertIdx = problem_.variables().index(*vIt);
+        int vIdxGlobal = problem_.variables().index(*vIt);
 
-        InteractionVolume& interactionVolume = asImp_().interactionVolumes_[globalVertIdx];
+        InteractionVolume& interactionVolume = asImp_().interactionVolumes_[vIdxGlobal];
 
         if (interactionVolume.getElementNumber() == 8)
         {
@@ -1700,16 +1700,16 @@ void FvMpfaL3dInteractionVolumeContainerAdaptive<TypeTag>::storeInteractionVolum
             asImp_().addRealFluxFaceArea_(interactionVolume.getFaceArea(4, 0), globalIdx5, interactionVolume.getIndexOnElement(4, 0));
             asImp_().addRealFluxFaceArea_(interactionVolume.getFaceArea(5, 0), globalIdx6, interactionVolume.getIndexOnElement(5, 0));
 
-            faceVertices_[globalIdx1][interactionVolume.getIndexOnElement(0, 0)].insert(globalVertIdx);
-            faceVertices_[globalIdx1][interactionVolume.getIndexOnElement(0, 1)].insert(globalVertIdx);
-            faceVertices_[globalIdx1][interactionVolume.getIndexOnElement(0, 2)].insert(globalVertIdx);
-            faceVertices_[globalIdx2][interactionVolume.getIndexOnElement(1, 0)].insert(globalVertIdx);
-            faceVertices_[globalIdx2][interactionVolume.getIndexOnElement(1, 1)].insert(globalVertIdx);
-            faceVertices_[globalIdx2][interactionVolume.getIndexOnElement(1, 2)].insert(globalVertIdx);
-            faceVertices_[globalIdx3][interactionVolume.getIndexOnElement(2, 0)].insert(globalVertIdx);
-            faceVertices_[globalIdx4][interactionVolume.getIndexOnElement(3, 1)].insert(globalVertIdx);
-            faceVertices_[globalIdx5][interactionVolume.getIndexOnElement(4, 0)].insert(globalVertIdx);
-            faceVertices_[globalIdx6][interactionVolume.getIndexOnElement(5, 0)].insert(globalVertIdx);
+            faceVertices_[globalIdx1][interactionVolume.getIndexOnElement(0, 0)].insert(vIdxGlobal);
+            faceVertices_[globalIdx1][interactionVolume.getIndexOnElement(0, 1)].insert(vIdxGlobal);
+            faceVertices_[globalIdx1][interactionVolume.getIndexOnElement(0, 2)].insert(vIdxGlobal);
+            faceVertices_[globalIdx2][interactionVolume.getIndexOnElement(1, 0)].insert(vIdxGlobal);
+            faceVertices_[globalIdx2][interactionVolume.getIndexOnElement(1, 1)].insert(vIdxGlobal);
+            faceVertices_[globalIdx2][interactionVolume.getIndexOnElement(1, 2)].insert(vIdxGlobal);
+            faceVertices_[globalIdx3][interactionVolume.getIndexOnElement(2, 0)].insert(vIdxGlobal);
+            faceVertices_[globalIdx4][interactionVolume.getIndexOnElement(3, 1)].insert(vIdxGlobal);
+            faceVertices_[globalIdx5][interactionVolume.getIndexOnElement(4, 0)].insert(vIdxGlobal);
+            faceVertices_[globalIdx6][interactionVolume.getIndexOnElement(5, 0)].insert(vIdxGlobal);
 
             if (interactionVolume.getHangingNodeType() != InteractionVolume::twoSmallCells)
             {
@@ -1728,20 +1728,20 @@ void FvMpfaL3dInteractionVolumeContainerAdaptive<TypeTag>::storeInteractionVolum
                 asImp_().addRealFluxFaceArea_(interactionVolume.getFaceArea(7, 1), globalIdx8, interactionVolume.getIndexOnElement(7, 1));
                 asImp_().addRealFluxFaceArea_(interactionVolume.getFaceArea(7, 2), globalIdx8, interactionVolume.getIndexOnElement(7, 2));
 
-                faceVertices_[globalIdx3][interactionVolume.getIndexOnElement(2, 1)].insert(globalVertIdx);
-                faceVertices_[globalIdx3][interactionVolume.getIndexOnElement(2, 2)].insert(globalVertIdx);
-                faceVertices_[globalIdx4][interactionVolume.getIndexOnElement(3, 0)].insert(globalVertIdx);
-                faceVertices_[globalIdx4][interactionVolume.getIndexOnElement(3, 2)].insert(globalVertIdx);
-                faceVertices_[globalIdx5][interactionVolume.getIndexOnElement(4, 1)].insert(globalVertIdx);
-                faceVertices_[globalIdx5][interactionVolume.getIndexOnElement(4, 2)].insert(globalVertIdx);
-                faceVertices_[globalIdx6][interactionVolume.getIndexOnElement(5, 1)].insert(globalVertIdx);
-                faceVertices_[globalIdx6][interactionVolume.getIndexOnElement(5, 2)].insert(globalVertIdx);
-                faceVertices_[globalIdx7][interactionVolume.getIndexOnElement(6, 0)].insert(globalVertIdx);
-                faceVertices_[globalIdx7][interactionVolume.getIndexOnElement(6, 1)].insert(globalVertIdx);
-                faceVertices_[globalIdx7][interactionVolume.getIndexOnElement(6, 2)].insert(globalVertIdx);
-                faceVertices_[globalIdx8][interactionVolume.getIndexOnElement(7, 0)].insert(globalVertIdx);
-                faceVertices_[globalIdx8][interactionVolume.getIndexOnElement(7, 1)].insert(globalVertIdx);
-                faceVertices_[globalIdx8][interactionVolume.getIndexOnElement(7, 2)].insert(globalVertIdx);
+                faceVertices_[globalIdx3][interactionVolume.getIndexOnElement(2, 1)].insert(vIdxGlobal);
+                faceVertices_[globalIdx3][interactionVolume.getIndexOnElement(2, 2)].insert(vIdxGlobal);
+                faceVertices_[globalIdx4][interactionVolume.getIndexOnElement(3, 0)].insert(vIdxGlobal);
+                faceVertices_[globalIdx4][interactionVolume.getIndexOnElement(3, 2)].insert(vIdxGlobal);
+                faceVertices_[globalIdx5][interactionVolume.getIndexOnElement(4, 1)].insert(vIdxGlobal);
+                faceVertices_[globalIdx5][interactionVolume.getIndexOnElement(4, 2)].insert(vIdxGlobal);
+                faceVertices_[globalIdx6][interactionVolume.getIndexOnElement(5, 1)].insert(vIdxGlobal);
+                faceVertices_[globalIdx6][interactionVolume.getIndexOnElement(5, 2)].insert(vIdxGlobal);
+                faceVertices_[globalIdx7][interactionVolume.getIndexOnElement(6, 0)].insert(vIdxGlobal);
+                faceVertices_[globalIdx7][interactionVolume.getIndexOnElement(6, 1)].insert(vIdxGlobal);
+                faceVertices_[globalIdx7][interactionVolume.getIndexOnElement(6, 2)].insert(vIdxGlobal);
+                faceVertices_[globalIdx8][interactionVolume.getIndexOnElement(7, 0)].insert(vIdxGlobal);
+                faceVertices_[globalIdx8][interactionVolume.getIndexOnElement(7, 1)].insert(vIdxGlobal);
+                faceVertices_[globalIdx8][interactionVolume.getIndexOnElement(7, 2)].insert(vIdxGlobal);
             }
         }
 
diff --git a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dpressure2p.hh b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dpressure2p.hh
index 9b98243fe8..db1b1c6238 100644
--- a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dpressure2p.hh
+++ b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dpressure2p.hh
@@ -568,9 +568,9 @@ void FvMpfaL3dPressure2p<TypeTag>::initializeMatrixRowSize()
 
         for (int vIdx = 0; vIdx < numVertices; vIdx++)
         {
-            int globalVertIdx = problem_.variables().vertexMapper().map(*eIt, vIdx, dim);
+            int vIdxGlobal = problem_.variables().vertexMapper().map(*eIt, vIdx, dim);
 
-            InteractionVolume& interactionVolume = interactionVolumes_.interactionVolume(globalVertIdx);
+            InteractionVolume& interactionVolume = interactionVolumes_.interactionVolume(vIdxGlobal);
 
             for (int subVolumeIdx = 0; subVolumeIdx < InteractionVolume::subVolumeTotalNum; subVolumeIdx++)
             {
@@ -609,9 +609,9 @@ void FvMpfaL3dPressure2p<TypeTag>::initializeMatrixIndices()
 
         for (int vIdx = 0; vIdx < numVertices; vIdx++)
         {
-            int globalVertIdx = problem_.variables().vertexMapper().map(*eIt, vIdx, dim);
+            int vIdxGlobal = problem_.variables().vertexMapper().map(*eIt, vIdx, dim);
 
-            InteractionVolume& interactionVolume = interactionVolumes_.interactionVolume(globalVertIdx);
+            InteractionVolume& interactionVolume = interactionVolumes_.interactionVolume(vIdxGlobal);
             for (int subVolumeIdx = 0; subVolumeIdx < InteractionVolume::subVolumeTotalNum; subVolumeIdx++)
             {
                 if (interactionVolume.hasSubVolumeElement(subVolumeIdx))
@@ -639,9 +639,9 @@ void FvMpfaL3dPressure2p<TypeTag>::assemble()
     VertexIterator vEndIt = problem_.gridView().template end<dim>();
     for (VertexIterator vIt = problem_.gridView().template begin<dim>(); vIt != vEndIt; ++vIt)
     {
-        int globalVertIdx = problem_.variables().index(*vIt);
+        int vIdxGlobal = problem_.variables().index(*vIt);
 
-        InteractionVolume& interactionVolume = interactionVolumes_.interactionVolume(globalVertIdx);
+        InteractionVolume& interactionVolume = interactionVolumes_.interactionVolume(vIdxGlobal);
 
         // inner interactionvolume
         if (interactionVolume.isInnerVolume())
diff --git a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dpressure2padaptive.hh b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dpressure2padaptive.hh
index 5fa5d4d547..1e44a01c11 100644
--- a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dpressure2padaptive.hh
+++ b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dpressure2padaptive.hh
@@ -300,9 +300,9 @@ void FvMpfaL3dPressure2pAdaptive<TypeTag>::initializeMatrixRowSize()
 
         for (int vIdx = 0; vIdx < numVertices; vIdx++)
         {
-            int globalVertIdx = problem_.variables().vertexMapper().map(*eIt, vIdx, dim);
+            int vIdxGlobal = problem_.variables().vertexMapper().map(*eIt, vIdx, dim);
 
-            InteractionVolume& interactionVolume = this->interactionVolumes_.interactionVolume(globalVertIdx);
+            InteractionVolume& interactionVolume = this->interactionVolumes_.interactionVolume(vIdxGlobal);
 
             for (int subVolumeIdx = 0; subVolumeIdx < InteractionVolume::subVolumeTotalNum; subVolumeIdx++)
             {
@@ -321,7 +321,7 @@ void FvMpfaL3dPressure2pAdaptive<TypeTag>::initializeMatrixRowSize()
                             {
                                 int globalVertIdxJ = problem_.variables().vertexMapper().map(*neighbor, vIdx, dim);
 
-                                if (globalVertIdxJ != globalVertIdx)
+                                if (globalVertIdxJ != vIdxGlobal)
                                 {
                                     InteractionVolume& interactionVolumeJ = this->interactionVolumes_.interactionVolume(
                                                                                                                         globalVertIdxJ);
@@ -389,9 +389,9 @@ void FvMpfaL3dPressure2pAdaptive<TypeTag>::initializeMatrixIndices()
 
         for (int vIdx = 0; vIdx < numVertices; vIdx++)
         {
-            int globalVertIdx = problem_.variables().vertexMapper().map(*eIt, vIdx, dim);
+            int vIdxGlobal = problem_.variables().vertexMapper().map(*eIt, vIdx, dim);
 
-            InteractionVolume& interactionVolume = this->interactionVolumes_.interactionVolume(globalVertIdx);
+            InteractionVolume& interactionVolume = this->interactionVolumes_.interactionVolume(vIdxGlobal);
             for (int subVolumeIdx = 0; subVolumeIdx < InteractionVolume::subVolumeTotalNum; subVolumeIdx++)
             {
                 if (interactionVolume.hasSubVolumeElement(subVolumeIdx))
@@ -435,9 +435,9 @@ void FvMpfaL3dPressure2pAdaptive<TypeTag>::assemble()
             continue;
         }
 #endif
-        int globalVertIdx = problem_.variables().index(*vIt);
+        int vIdxGlobal = problem_.variables().index(*vIt);
 
-        InteractionVolume& interactionVolume = this->interactionVolumes_.interactionVolume(globalVertIdx);
+        InteractionVolume& interactionVolume = this->interactionVolumes_.interactionVolume(vIdxGlobal);
 
         // inner interactionvolume
         if (interactionVolume.isInnerVolume())
diff --git a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dpressurevelocity2p.hh b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dpressurevelocity2p.hh
index c16a3b4764..232a4dba4c 100644
--- a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dpressurevelocity2p.hh
+++ b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dpressurevelocity2p.hh
@@ -218,9 +218,9 @@ void FvMpfaL3dPressureVelocity2p<TypeTag>::calculateVelocity()
     VertexIterator vEndIt = problem_.gridView().template end<dim>();
     for (VertexIterator vIt = problem_.gridView().template begin<dim>(); vIt != vEndIt; ++vIt)
     {
-        int globalVertIdx = problem_.variables().index(*vIt);
+        int vIdxGlobal = problem_.variables().index(*vIt);
 
-        InteractionVolume& interactionVolume = this->interactionVolumes_.interactionVolume(globalVertIdx);
+        InteractionVolume& interactionVolume = this->interactionVolumes_.interactionVolume(vIdxGlobal);
 
         // inner interactionvolume
         if (interactionVolume.isInnerVolume())
@@ -318,10 +318,10 @@ void FvMpfaL3dPressureVelocity2p<TypeTag>::calculateVelocity(const Intersection&
     {
         int localVertIdx = referenceElement.subEntity(indexInInside, 1, vIdx, dim);
 
-        int globalVertIdx = problem_.variables().index(
+        int vIdxGlobal = problem_.variables().index(
                 *((*elementPtrI).template subEntity < dim > (localVertIdx)));
 
-        InteractionVolume& interactionVolume = this->interactionVolumes_.interactionVolume(globalVertIdx);
+        InteractionVolume& interactionVolume = this->interactionVolumes_.interactionVolume(vIdxGlobal);
 
         if (interactionVolume.isInnerVolume())
         {
diff --git a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dpressurevelocity2padaptive.hh b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dpressurevelocity2padaptive.hh
index fe2a15eff6..5bebaee54d 100644
--- a/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dpressurevelocity2padaptive.hh
+++ b/dumux/decoupled/2p/diffusion/fvmpfa/lmethod/fvmpfal3dpressurevelocity2padaptive.hh
@@ -219,9 +219,9 @@ void FvMpfaL3dPressureVelocity2pAdaptive<TypeTag>::calculateVelocity()
     VertexIterator vEndIt = problem_.gridView().template end<dim>();
     for (VertexIterator vIt = problem_.gridView().template begin<dim>(); vIt != vEndIt; ++vIt)
     {
-        int globalVertIdx = problem_.variables().index(*vIt);
+        int vIdxGlobal = problem_.variables().index(*vIt);
 
-        InteractionVolume& interactionVolume = this->interactionVolumes_.interactionVolume(globalVertIdx);
+        InteractionVolume& interactionVolume = this->interactionVolumes_.interactionVolume(vIdxGlobal);
 
         // inner interactionvolume
         if (interactionVolume.isInnerVolume())
@@ -337,20 +337,20 @@ void FvMpfaL3dPressureVelocity2pAdaptive<TypeTag>::calculateVelocity(const Inter
         cellDataJ.fluxData().setUpwindPotential(nPhaseIdx, indexInOutside, 0);
     }
 
-    std::set<int> globalVertIdx;
+    std::set<int> vIdxGlobal;
 
     if (levelI >= levelJ)
     {
-        globalVertIdx = this->interactionVolumes_.faceVerticeIndices(globalIdxI, indexInInside);
+        vIdxGlobal = this->interactionVolumes_.faceVerticeIndices(globalIdxI, indexInInside);
     }
     else
     {
-        globalVertIdx = this->interactionVolumes_.faceVerticeIndices(globalIdxJ, indexInOutside);
+        vIdxGlobal = this->interactionVolumes_.faceVerticeIndices(globalIdxJ, indexInOutside);
     }
 
-    std::set<int>::iterator itEnd = globalVertIdx.end();
+    std::set<int>::iterator itEnd = vIdxGlobal.end();
 
-    for (std::set<int>::iterator vIdxIt = globalVertIdx.begin(); vIdxIt != itEnd; ++vIdxIt)
+    for (std::set<int>::iterator vIdxIt = vIdxGlobal.begin(); vIdxIt != itEnd; ++vIdxIt)
     {
         InteractionVolume& interactionVolume = this->interactionVolumes_.interactionVolume(*vIdxIt);
 
diff --git a/dumux/decoupled/2p/diffusion/fvmpfa/omethod/fvmpfao2dpressure2p.hh b/dumux/decoupled/2p/diffusion/fvmpfa/omethod/fvmpfao2dpressure2p.hh
index 435f3409b5..8588f18090 100644
--- a/dumux/decoupled/2p/diffusion/fvmpfa/omethod/fvmpfao2dpressure2p.hh
+++ b/dumux/decoupled/2p/diffusion/fvmpfa/omethod/fvmpfao2dpressure2p.hh
@@ -1355,9 +1355,9 @@ void FvMpfaO2dPressure2p<TypeTag>::assemble()
     VertexIterator vEndIt = problem_.gridView().template end<dim>();
     for (VertexIterator vIt = problem_.gridView().template begin<dim>(); vIt != vEndIt; ++vIt)
     {
-        int globalVertIdx = problem_.variables().index(*vIt);
+        int vIdxGlobal = problem_.variables().index(*vIt);
 
-        InteractionVolume& interactionVolume = interactionVolumes_[globalVertIdx];
+        InteractionVolume& interactionVolume = interactionVolumes_[vIdxGlobal];
 
         if (interactionVolume.isInnerVolume())
         {
diff --git a/dumux/decoupled/2p/diffusion/fvmpfa/omethod/fvmpfao2dpressurevelocity2p.hh b/dumux/decoupled/2p/diffusion/fvmpfa/omethod/fvmpfao2dpressurevelocity2p.hh
index 66973867e8..c5a50f7cb2 100644
--- a/dumux/decoupled/2p/diffusion/fvmpfa/omethod/fvmpfao2dpressurevelocity2p.hh
+++ b/dumux/decoupled/2p/diffusion/fvmpfa/omethod/fvmpfao2dpressurevelocity2p.hh
@@ -225,9 +225,9 @@ void FvMpfaO2dPressureVelocity2p<TypeTag>::calculateVelocity()
     VertexIterator vEndIt = problem_.gridView().template end<dim>();
     for (VertexIterator vIt = problem_.gridView().template begin<dim>(); vIt != vEndIt; ++vIt)
     {
-        int globalVertIdx = problem_.variables().index(*vIt);
+        int vIdxGlobal = problem_.variables().index(*vIt);
 
-        InteractionVolume& interactionVolume = this->interactionVolumes_[globalVertIdx];
+        InteractionVolume& interactionVolume = this->interactionVolumes_[vIdxGlobal];
 
         if (interactionVolume.isInnerVolume())
         {
@@ -317,10 +317,10 @@ void FvMpfaO2dPressureVelocity2p<TypeTag>::calculateVelocity(const Intersection&
     {
         int localVertIdx = referenceElement.subEntity(indexInInside, dim - 1, vIdx, dim);
 
-        int globalVertIdx = problem_.variables().index(
+        int vIdxGlobal = problem_.variables().index(
                 *((*elementPtrI).template subEntity < dim > (localVertIdx)));
 
-        InteractionVolume& interactionVolume = this->interactionVolumes_[globalVertIdx];
+        InteractionVolume& interactionVolume = this->interactionVolumes_[vIdxGlobal];
 
         if (interactionVolume.isInnerVolume())
         {
diff --git a/dumux/decoupled/2p2c/fv3dpressure2p2cadaptive.hh b/dumux/decoupled/2p2c/fv3dpressure2p2cadaptive.hh
index c217bde816..a6b100bfe8 100644
--- a/dumux/decoupled/2p2c/fv3dpressure2p2cadaptive.hh
+++ b/dumux/decoupled/2p2c/fv3dpressure2p2cadaptive.hh
@@ -1684,9 +1684,9 @@ int FV3dPressure2P2CAdaptive<TypeTag>::computeTransmissibilities(const Intersect
         #endif
 
         // get Interaction Volume object
-        int globalVertIdx = problem().variables().index(*outerCornerPtr);
+        int vIdxGlobal = problem().variables().index(*outerCornerPtr);
         InteractionVolume& interactionVolume
-                        = interactionVolumesContainer_->interactionVolume(globalVertIdx);
+                        = interactionVolumesContainer_->interactionVolume(vIdxGlobal);
 
         // abort if we are on boundary
         if(interactionVolume.isBoundaryInteractionVolume())
@@ -1754,10 +1754,10 @@ int FV3dPressure2P2CAdaptive<TypeTag>::computeTransmissibilities(const Intersect
                     if(vPtrSmall != outerCornerPtr
                             && ((vertexOnInterface - vertexOnElement).two_norm()<1e-5))
                     {
-                        int globalVertIdx = problem().variables().index(*vPtrSmall);
+                        int vIdxGlobal = problem().variables().index(*vPtrSmall);
                         // acess interactionVolume
                         InteractionVolume& interactionVolume
-                            = interactionVolumesContainer_->interactionVolume(globalVertIdx);
+                            = interactionVolumesContainer_->interactionVolume(vIdxGlobal);
                         if(interactionVolume.isBoundaryInteractionVolume())
                             continue;
 
diff --git a/dumux/freeflow/stokes/stokesvolumevariables.hh b/dumux/freeflow/stokes/stokesvolumevariables.hh
index aa84b6b2e0..4ffffb350e 100644
--- a/dumux/freeflow/stokes/stokesvolumevariables.hh
+++ b/dumux/freeflow/stokes/stokesvolumevariables.hh
@@ -126,7 +126,7 @@ public:
         Scalar h = Implementation::enthalpy_(fluidState, paramCache, phaseIdx);
         fluidState.setEnthalpy(phaseIdx, h);
 
-//        int globalVertIdx = problem.model().dofMapper().map(element, scvIdx, dim);
+//        int vIdxGlobal = problem.model().dofMapper().map(element, scvIdx, dim);
     }
 
     /*!
diff --git a/dumux/geomechanics/el2p/el2pmodel.hh b/dumux/geomechanics/el2p/el2pmodel.hh
index f3ad422ebd..a89c99e33a 100644
--- a/dumux/geomechanics/el2p/el2pmodel.hh
+++ b/dumux/geomechanics/el2p/el2pmodel.hh
@@ -152,26 +152,26 @@ public:
                          const Entity &entity)
     {
         // vertex index
-        int dofIdx = this->dofMapper().map(entity);
+        int dofIdxGlobal = this->dofMapper().map(entity);
 
         // write phase state
         if (!outStream.good()) {
             DUNE_THROW(Dune::IOError,
                        "Could not serialize vertex "
-                       << dofIdx);
+                       << dofIdxGlobal);
         }
         int numScv = this->gridView().size(dim);
         // get p and S entries for this vertex
         for (int eqIdx = 0; eqIdx < numEq-dim; ++eqIdx) {
-            outStream << this->curSol().base()[dofIdx*(numEq-dim) + eqIdx][0]<<" ";
+            outStream << this->curSol().base()[dofIdxGlobal*(numEq-dim) + eqIdx][0]<<" ";
         }
         // get ux, uy, uz entries for this vertex
         for (int j = 0; j< dim; ++j)
-            outStream << this->curSol().base()[numScv*(numEq-dim) + dofIdx*dim + j][0] <<" ";
+            outStream << this->curSol().base()[numScv*(numEq-dim) + dofIdxGlobal*dim + j][0] <<" ";
 
-        int vIdx = this->dofMapper().map(entity);
+        int vIdxGlobal = this->dofMapper().map(entity);
         if (!outStream.good())
-            DUNE_THROW(Dune::IOError, "Could not serialize vertex " << vIdx);
+            DUNE_THROW(Dune::IOError, "Could not serialize vertex " << vIdxGlobal);
     }
 
     /*!
@@ -192,20 +192,20 @@ public:
     template<class Entity>
     void deserializeEntity(std::istream &inStream, const Entity &entity)
     {
-        int dofIdx = this->dofMapper().map(entity);
+        int dofIdxGlobal = this->dofMapper().map(entity);
 
         if (!inStream.good()){
                 DUNE_THROW(Dune::IOError,
                            "Could not deserialize vertex "
-                           << dofIdx);
+                           << dofIdxGlobal);
         }
         int numScv = this->gridView().size(dim);
         for (int eqIdx = 0; eqIdx < numEq-dim; ++eqIdx) {
         // read p and S entries for this vertex
-        inStream >> this->curSol().base()[dofIdx*(numEq-dim) + eqIdx][0];}
+        inStream >> this->curSol().base()[dofIdxGlobal*(numEq-dim) + eqIdx][0];}
         for (int j = 0; j< dim; ++j){
             // read ux, uy, uz entries for this vertex
-            inStream >> this->curSol().base()[numScv*(numEq-dim) + dofIdx*dim + j][0];}
+            inStream >> this->curSol().base()[numScv*(numEq-dim) + dofIdxGlobal*dim + j][0];}
     }
 
 
diff --git a/dumux/implicit/box/boxassembler.hh b/dumux/implicit/box/boxassembler.hh
index 1b25654d9f..5e79e0376c 100644
--- a/dumux/implicit/box/boxassembler.hh
+++ b/dumux/implicit/box/boxassembler.hh
@@ -119,11 +119,11 @@ private:
 
             // if yes, the element color is also red, else it is not
             // red, i.e. green for the mean time
-            int globalElemIdx = this->elementMapper_().map(*eIt);
+            int eIdxGlobal = this->elementMapper_().map(*eIt);
             if (isRed)
-                this->elementColor_[globalElemIdx] = ParentType::Red;
+                this->elementColor_[eIdxGlobal] = ParentType::Red;
             else
-                this->elementColor_[globalElemIdx] = ParentType::Green;
+                this->elementColor_[eIdxGlobal] = ParentType::Green;
         }
 
         // Mark yellow vertices (as orange for the mean time)
@@ -309,8 +309,8 @@ private:
     void assembleElement_(const Element &element)
     {
         if (this->enablePartialReassemble_()) {
-            int globalElemIdx = this->model_().elementMapper().map(element);
-            if (this->elementColor_[globalElemIdx] == ParentType::Green) {
+            int eIdxGlobal = this->model_().elementMapper().map(element);
+            if (this->elementColor_[eIdxGlobal] == ParentType::Green) {
                 ++this->greenElems_;
 
                 assembleGreenElement_(element);
diff --git a/dumux/implicit/box/intersectiontovertexbc.hh b/dumux/implicit/box/intersectiontovertexbc.hh
index 970343ba9f..fc9f5bc6b5 100644
--- a/dumux/implicit/box/intersectiontovertexbc.hh
+++ b/dumux/implicit/box/intersectiontovertexbc.hh
@@ -83,11 +83,11 @@ public:
                 for (int faceVertIdx = 0; faceVertIdx < numFaceVerts; ++faceVertIdx)
                 {
                     int elemVertIdx = refElement.subEntity(faceIdx, 1, faceVertIdx, dim);
-                    int globalVertIdx = problem.vertexMapper().map(*eIt, elemVertIdx, dim);
+                    int vIdxGlobal = problem.vertexMapper().map(*eIt, elemVertIdx, dim);
 
                     for (int eqIdx = 0; eqIdx < numEq; eqIdx++)
                       if (bcTypes.isDirichlet(eqIdx))
-                          vertexBC[globalVertIdx].setDirichlet(eqIdx);
+                          vertexBC[vIdxGlobal].setDirichlet(eqIdx);
                 }
             }
         }
diff --git a/dumux/implicit/cellcentered/ccassembler.hh b/dumux/implicit/cellcentered/ccassembler.hh
index a94a61a0db..228b9ca708 100644
--- a/dumux/implicit/cellcentered/ccassembler.hh
+++ b/dumux/implicit/cellcentered/ccassembler.hh
@@ -182,8 +182,8 @@ private:
     void assembleElement_(const Element &element)
     {
         if (this->enablePartialReassemble_()) {
-            int globalElemIdx = this->model_().elementMapper().map(element);
-            if (this->elementColor_[globalElemIdx] == ParentType::Green) {
+            int eIdxGlobal = this->model_().elementMapper().map(element);
+            if (this->elementColor_[eIdxGlobal] == ParentType::Green) {
                 ++this->greenElems_;
 
                 assembleGreenElement_(element);
diff --git a/dumux/io/artgridcreator.hh b/dumux/io/artgridcreator.hh
index 4227188854..af2f0c6100 100644
--- a/dumux/io/artgridcreator.hh
+++ b/dumux/io/artgridcreator.hh
@@ -278,7 +278,7 @@ public:
             Dune::FieldVector<double,3> point(0);
 #if PLOT
             std::cout << "=====================================" << std::endl;
-            std::cout << "globalElemIdx " << i << std::endl;
+            std::cout << "eIdxGlobal " << i << std::endl;
             std::cout << "=====================================" << std::endl;
 #endif
             int edgeIdx = 0;
diff --git a/dumux/geomechanics/el2p/el2passembler.hh b/dumux/geomechanics/el2p/el2passembler.hh
index 9f9fb05424..6fd017151f 100644
--- a/dumux/geomechanics/el2p/el2passembler.hh
+++ b/dumux/geomechanics/el2p/el2passembler.hh
@@ -341,11 +341,11 @@ public:
 
             // if yes, the element color is also red, else it is not
             // red, i.e. green for the mean time
-            int globalElemIdx = elementMapper_().map(*eIt);
+            int eIdxGlobal = elementMapper_().map(*eIt);
             if (isRed)
-                elementColor_[globalElemIdx] = Red;
+                elementColor_[eIdxGlobal] = Red;
             else
-                elementColor_[globalElemIdx] = Green;
+                elementColor_[eIdxGlobal] = Green;
         }
 
         // Mark yellow vertices (as orange for the mean time)
@@ -442,13 +442,13 @@ public:
     /*!
      * \brief Returns the reassemble color of a vertex
      *
      * \param globalVertIdx The global index of the vertex.
      */
-    int vertexColor(int globalVertIdx) const
+    int vertexColor(int vIdxGlobal) const
     {
         if (!enablePartialReassemble)
             return Red; // reassemble unconditionally!
-        return vertexColor_[globalVertIdx];
+        return vertexColor_[vIdxGlobal];
     }
 
     /*!
@@ -442,13 +442,13 @@ public:
      * \brief Returns the reassemble color of a vertex
      *
-     * \param globalVertIdx The global index of the vertex.
+     * \param vIdxGlobal The global index of the vertex.
      */
diff --git a/dumux/geomechanics/el2p/el2pbasemodel.hh b/dumux/geomechanics/el2p/el2pbasemodel.hh
index 62ebbee0eb..a54accc6b0 100644
--- a/dumux/geomechanics/el2p/el2pbasemodel.hh
+++ b/dumux/geomechanics/el2p/el2pbasemodel.hh
@@ -396,12 +396,12 @@ public:
      * \brief Returns the relative error between two vectors of
      *        primary variables.
      *
      * \param dofIdx The global index of the control volume's
      *               associated degree of freedom
      * \param priVars1 The first vector of primary variables
      * \param priVars2 The second vector of primary variables
      */
-    Scalar relativeErrorDof(const int dofIdx,
+    Scalar relativeErrorDof(const int dofIdxGlobal,
                             const PrimaryVariables &priVars1,
                             const PrimaryVariables &priVars2)
     {
@@ -558,17 +558,17 @@ public:
     void serializeEntity(std::ostream &outstream,
                          const Entity &entity)
     {
-        int dofIdx = dofMapper().map(entity);
+        int dofIdxGlobal = dofMapper().map(entity);
 
         // write phase state
         if (!outstream.good()) {
             DUNE_THROW(Dune::IOError,
                        "Could not serialize vertex "
-                       << dofIdx);
+                       << dofIdxGlobal);
         }
 
         for (int eqIdx = 0; eqIdx < numEq; ++eqIdx) {
-            outstream << curSol()[dofIdx][eqIdx] << " ";
+            outstream << curSol()[dofIdxGlobal][eqIdx] << " ";
         }
     }
 
@@ -586,14 +586,14 @@ public:
     void deserializeEntity(std::istream &instream,
                            const Entity &entity)
     {
-        int dofIdx = dofMapper().map(entity);
+        int dofIdxGlobal = dofMapper().map(entity);
 
         for (int eqIdx = 0; eqIdx < numEq; ++eqIdx) {
             if (!instream.good())
                 DUNE_THROW(Dune::IOError,
                            "Could not deserialize vertex "
-                           << dofIdx);
-            instream >> curSol()[dofIdx][eqIdx];
+                           << dofIdxGlobal);
+            instream >> curSol()[dofIdxGlobal][eqIdx];
         }
     }
 
@@ -979,8 +979,8 @@ protected:
                                                                    1,
                                                                    faceVertIdx,
                                                                    dim);
-                            int globalVertIdx = vertexMapper().map(*eIt, elemVertIdx, dim);
-                            boundaryIndices_[globalVertIdx] = true;
+                            int vIdxGlobal = vertexMapper().map(*eIt, elemVertIdx, dim);
+                            boundaryIndices_[vIdxGlobal] = true;
                         }
                     }
                     else 
@@ -396,12 +396,12 @@ public:
      *        primary variables.
      *
-     * \param dofIdx The global index of the control volume's
-     *               associated degree of freedom
+     * \param dofIdxGlobal The global index of the control volume's
+     *                     associated degree of freedom
      * \param priVars1 The first vector of primary variables
      * \param priVars2 The second vector of primary variables
diff --git a/dumux/implicit/common/implicitassembler.hh b/dumux/implicit/common/implicitassembler.hh
index 6bfc13b9de..7e7e27ac01 100644
--- a/dumux/implicit/common/implicitassembler.hh
+++ b/dumux/implicit/common/implicitassembler.hh
@@ -340,13 +340,13 @@ public:
     /*!
      * \brief Returns the reassemble color of a vertex
      *
      * \param globalVertIdx The global index of the vertex.
      */
-    int vertexColor(const int globalVertIdx) const
+    int vertexColor(const int vIdxGlobal) const
     {
         if (!enablePartialReassemble_())
             return Red; // reassemble unconditionally!
-        return vertexColor_[globalVertIdx];
+        return vertexColor_[vIdxGlobal];
     }
 
     /*!
@@ -340,13 +340,13 @@ public:
      * \brief Returns the reassemble color of a vertex
      *
-     * \param globalVertIdx The global index of the vertex.
+     * \param vIdxGlobal The global index of the vertex.
      */
diff --git a/dumux/implicit/common/implicitmodel.hh b/dumux/implicit/common/implicitmodel.hh
index 2954f01a3f..82bbfa61ac 100644
--- a/dumux/implicit/common/implicitmodel.hh
+++ b/dumux/implicit/common/implicitmodel.hh
@@ -397,12 +397,12 @@ public:
      * \brief Returns the relative error between two vectors of
      *        primary variables.
      *
      * \param dofIdx The global index of the control volume's
      *               associated degree of freedom
      * \param priVars1 The first vector of primary variables
      * \param priVars2 The second vector of primary variables
      */
-    Scalar relativeErrorDof(const int dofIdx,
+    Scalar relativeErrorDof(const int dofIdxGlobal,
                             const PrimaryVariables &priVars1,
                             const PrimaryVariables &priVars2)
     {
@@ -559,17 +559,17 @@ public:
     void serializeEntity(std::ostream &outstream,
                          const Entity &entity)
     {
-        int dofIdx = dofMapper().map(entity);
+        int dofIdxGlobal = dofMapper().map(entity);
         
         // write phase state
         if (!outstream.good()) {
             DUNE_THROW(Dune::IOError,
                        "Could not serialize vertex "
-                       << dofIdx);
+                       << dofIdxGlobal);
         }
 
         for (int eqIdx = 0; eqIdx < numEq; ++eqIdx) {
-            outstream << curSol()[dofIdx][eqIdx] << " ";
+            outstream << curSol()[dofIdxGlobal][eqIdx] << " ";
         }
     }
 
@@ -587,14 +587,14 @@ public:
     void deserializeEntity(std::istream &instream,
                            const Entity &entity)
     {
-        int dofIdx = dofMapper().map(entity);
+        int dofIdxGlobal = dofMapper().map(entity);
 
         for (int eqIdx = 0; eqIdx < numEq; ++eqIdx) {
             if (!instream.good())
                 DUNE_THROW(Dune::IOError,
                            "Could not deserialize vertex "
-                           << dofIdx);
-            instream >> curSol()[dofIdx][eqIdx];
+                           << dofIdxGlobal);
+            instream >> curSol()[dofIdxGlobal][eqIdx];
         }
     }
 
@@ -980,8 +980,8 @@ protected:
                                                                    1,
                                                                    faceVertIdx,
                                                                    dim);
-                            int globalVertIdx = vertexMapper().map(*eIt, elemVertIdx, dim);
-                            boundaryIndices_[globalVertIdx] = true;
+                            int vIdxGlobal = vertexMapper().map(*eIt, elemVertIdx, dim);
+                            boundaryIndices_[vIdxGlobal] = true;
                         }
                     }
                     else 
@@ -397,12 +397,12 @@ public:
      *        primary variables.
      *
-     * \param dofIdx The global index of the control volume's
-     *               associated degree of freedom
+     * \param dofIdxGlobal The global index of the control volume's
+     *                     associated degree of freedom
      * \param priVars1 The first vector of primary variables
      * \param priVars2 The second vector of primary variables
-- 
GitLab